import _JSXStyle from "next/dist/shared/lib/styled-jsx";
import Link from "next/link";
export default function IndexPage() {
    return <div className={"jsx-2339e3d61ab4470c"}>

      Hello World.{" "}

      <Link href="/about">

        <a className={"jsx-2339e3d61ab4470c"}>Abound</a>

      </Link>

      <_JSXStyle id={"2339e3d61ab4470c"}>{`a.jsx-2339e3d61ab4470c{color:${"#abcdef"}12}`}</_JSXStyle>

    </div>;
};
